summaryrefslogtreecommitdiff
path: root/src/select/select.h
diff options
context:
space:
mode:
authorJohn Mark Bell <jmb@netsurf-browser.org>2009-07-04 14:02:56 +0000
committerJohn Mark Bell <jmb@netsurf-browser.org>2009-07-04 14:02:56 +0000
commita3105d297fa8bb6bc8728d60a21b662d867688ae (patch)
tree57180314281f4c21201a8ae35bdff1d63a4416e3 /src/select/select.h
parent3b1a80cbb138c9c714efc0f32729506060c78c81 (diff)
downloadlibcss-a3105d297fa8bb6bc8728d60a21b662d867688ae.tar.gz
libcss-a3105d297fa8bb6bc8728d60a21b662d867688ae.tar.bz2
Ensure that any properties explicitly set to inherit on the root element are set to their initial values.
svn path=/trunk/libcss/; revision=8309
Diffstat (limited to 'src/select/select.h')
-rw-r--r--src/select/select.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/select/select.h b/src/select/select.h
index 1b3c702..320efd0 100644
--- a/src/select/select.h
+++ b/src/select/select.h
@@ -19,7 +19,8 @@ typedef struct prop_state {
uint32_t specificity; /* Specificity of property in result */
uint32_t set : 1, /* Whether property is set in result */
origin : 2, /* Origin of property in result */
- important : 1; /* Importance of property in result */
+ important : 1, /* Importance of property in result */
+ inherit : 1; /* Property is set to inherit */
} prop_state;
/**
@@ -61,7 +62,8 @@ static inline void advance_bytecode(css_style *style, uint32_t n_bytes)
style->bytecode = ((uint8_t *) style->bytecode) + n_bytes;
}
-bool outranks_existing(uint16_t op, bool important, css_select_state *state);
+bool outranks_existing(uint16_t op, bool important, css_select_state *state,
+ bool inherit);
#endif